Title: [250257] trunk/Tools
Revision
250257
Author
aakash_j...@apple.com
Date
2019-09-23 15:25:54 -0700 (Mon, 23 Sep 2019)

Log Message

[EWS] Rename CompileJSCOnly to CompileJSC
https://bugs.webkit.org/show_bug.cgi?id=202118

Reviewed by Jonathan Bedard.

* BuildSlaveSupport/ews-build/factories.py:
(JSCTestsFactory.__init__): Renamed CompileJSCOnly to CompileJSC.
* BuildSlaveSupport/ews-build/steps.py:
(CompileWebKit.evaluateCommand): Ditto.
(AnalyzeCompileWebKitResults.start): Ditto.
(CompileJSC): Changed step-name to 'compile-jsc' to better match with similar steps like 'compile-webkit'. 
(CompileJSCToT): Ditto for 'compile-jsc-tot'.
* BuildSlaveSupport/ews-build/steps_unittest.py: Renamed CompileJSCOnly to CompileJSC and CompileJSCOnlyToT to CompileJSCToT.

Modified Paths

Diff

Modified: trunk/Tools/BuildSlaveSupport/ews-build/factories.py (250256 => 250257)


--- trunk/Tools/BuildSlaveSupport/ews-build/factories.py	2019-09-23 22:16:47 UTC (rev 250256)
+++ trunk/Tools/BuildSlaveSupport/ews-build/factories.py	2019-09-23 22:25:54 UTC (rev 250257)
@@ -25,7 +25,7 @@
 from buildbot.steps import trigger
 
 from steps import (ApplyPatch, ApplyWatchList, CheckOutSource, CheckOutSpecificRevision, CheckPatchRelevance,
-                   CheckStyle, CompileJSCOnly, CompileJSCOnlyToT, CompileWebKit, ConfigureBuild,
+                   CheckStyle, CompileJSC, CompileWebKit, ConfigureBuild,
                    DownloadBuiltProduct, ExtractBuiltProduct, InstallGtkDependencies, InstallWpeDependencies, KillOldProcesses,
                    PrintConfiguration, ReRunJavaScriptCoreTests, RunAPITests, RunBindingsTests, RunEWSBuildbotCheckConfig, RunEWSUnitTests,
                    RunJavaScriptCoreTests, RunJavaScriptCoreTestsToT, RunWebKit1Tests, RunWebKitPerlTests,
@@ -118,7 +118,7 @@
 class JSCTestsFactory(Factory):
     def __init__(self, platform, configuration='release', architectures=None, additionalArguments=None, **kwargs):
         Factory.__init__(self, platform, configuration, architectures, False, additionalArguments, checkRelevance=True)
-        self.addStep(CompileJSCOnly(skipUpload=True))
+        self.addStep(CompileJSC(skipUpload=True))
         self.addStep(RunJavaScriptCoreTests())
         self.addStep(ReRunJavaScriptCoreTests())
         self.addStep(UnApplyPatchIfRequired())

Modified: trunk/Tools/BuildSlaveSupport/ews-build/steps.py (250256 => 250257)


--- trunk/Tools/BuildSlaveSupport/ews-build/steps.py	2019-09-23 22:16:47 UTC (rev 250256)
+++ trunk/Tools/BuildSlaveSupport/ews-build/steps.py	2019-09-23 22:25:54 UTC (rev 250257)
@@ -745,7 +745,7 @@
             elif platform == 'gtk':
                 steps_to_add.append(InstallGtkDependencies())
             if self.getProperty('group') == 'jsc':
-                steps_to_add.append(CompileJSCOnlyToT())
+                steps_to_add.append(CompileJSCToT())
             else:
                 steps_to_add.append(CompileWebKitToT())
             steps_to_add.append(AnalyzeCompileWebKitResults())
@@ -781,7 +781,7 @@
     def start(self):
         compile_tot_step = CompileWebKitToT.name
         if self.getProperty('group') == 'jsc':
-            compile_tot_step = CompileJSCOnlyToT.name
+            compile_tot_step = CompileJSCToT.name
         compile_webkit_tot_result = self.getStepResult(compile_tot_step)
 
         if compile_webkit_tot_result == FAILURE:
@@ -805,8 +805,8 @@
                 return step.results
 
 
-class CompileJSCOnly(CompileWebKit):
-    name = 'build-jsc'
+class CompileJSC(CompileWebKit):
+    name = 'compile-jsc'
     descriptionDone = ['Compiled JSC']
     command = ['perl', 'Tools/Scripts/build-jsc', WithProperties('--%(configuration)s')]
 
@@ -815,8 +815,8 @@
         return CompileWebKit.start(self)
 
 
-class CompileJSCOnlyToT(CompileJSCOnly):
-    name = 'build-jsc-tot'
+class CompileJSCToT(CompileJSC):
+    name = 'compile-jsc-tot'
 
     def doStepIf(self, step):
         return self.getProperty('patchFailedToBuild')

Modified: trunk/Tools/BuildSlaveSupport/ews-build/steps_unittest.py (250256 => 250257)


--- trunk/Tools/ChangeLog	2019-09-23 22:16:47 UTC (rev 250256)
+++ trunk/Tools/ChangeLog	2019-09-23 22:25:54 UTC (rev 250257)
@@ -1,3 +1,19 @@
+2019-09-23  Aakash Jain  <aakash_j...@apple.com>
+
+        [EWS] Rename CompileJSCOnly to CompileJSC
+        https://bugs.webkit.org/show_bug.cgi?id=202118
+
+        Reviewed by Jonathan Bedard.
+
+        * BuildSlaveSupport/ews-build/factories.py:
+        (JSCTestsFactory.__init__): Renamed CompileJSCOnly to CompileJSC.
+        * BuildSlaveSupport/ews-build/steps.py:
+        (CompileWebKit.evaluateCommand): Ditto.
+        (AnalyzeCompileWebKitResults.start): Ditto.
+        (CompileJSC): Changed step-name to 'compile-jsc' to better match with similar steps like 'compile-webkit'. 
+        (CompileJSCToT): Ditto for 'compile-jsc-tot'.
+        * BuildSlaveSupport/ews-build/steps_unittest.py: Renamed CompileJSCOnly to CompileJSC and CompileJSCOnlyToT to CompileJSCToT.
+
 2019-09-23  Wenson Hsieh  <wenson_hs...@apple.com>
 
         [iOS] Drop animation when dragging images from Photos to WebKit2 Mail compose is incorrect
_______________________________________________
webkit-changes mailing list
webkit-changes@lists.webkit.org
https://lists.webkit.org/mailman/listinfo/webkit-changes

Reply via email to
--- trunk/Tools/BuildSlaveSupport/ews-build/steps_unittest.py	2019-09-23 22:16:47 UTC (rev 250256)
+++ trunk/Tools/BuildSlaveSupport/ews-build/steps_unittest.py	2019-09-23 22:25:54 UTC (rev 250257)
@@ -36,7 +36,7 @@
 
 from steps import (AnalyzeAPITestsResults, AnalyzeCompileWebKitResults, AnalyzeLayoutTestsResults, ApplyPatch, ApplyWatchList, ArchiveBuiltProduct, ArchiveTestResults,
                    CheckOutSource, CheckOutSpecificRevision, CheckPatchRelevance, CheckStyle, CleanBuild, CleanUpGitIndexLock, CleanWorkingDirectory,
                    CompileJSCOnly, CompileJSCOnlyToT, CompileWebKit, CompileWebKitToT, ConfigureBuild,
                    DownloadBuiltProduct, ExtractBuiltProduct, ExtractTestResults, InstallGtkDependencies, InstallWpeDependencies, KillOldProcesses,
                    PrintConfiguration, ReRunAPITests, ReRunJavaScriptCoreTests, ReRunWebKitTests, RunAPITests, RunAPITestsWithoutPatch,
                    RunBindingsTests, RunEWSBuildbotCheckConfig, RunEWSUnitTests, RunJavaScriptCoreTests, RunJavaScriptCoreTestsToT, RunWebKit1Tests,
@@ -846,7 +846,7 @@
         return self.runStep()
 
 
-class TestCompileJSCOnly(BuildStepMixinAdditions, unittest.TestCase):
+class TestCompileJSC(BuildStepMixinAdditions, unittest.TestCase):
     def setUp(self):
         self.longMessage = True
         return self.setUpBuildStep()
@@ -855,7 +855,7 @@
         return self.tearDownBuildStep()
 
     def test_success(self):
-        self.setupStep(CompileJSCOnly())
+        self.setupStep(CompileJSC())
         self.setProperty('fullPlatform', 'jsc-only')
         self.setProperty('configuration', 'release')
         self.expectRemoteCommands(
@@ -869,7 +869,7 @@
         return self.runStep()
 
     def test_failure(self):
-        self.setupStep(CompileJSCOnly())
+        self.setupStep(CompileJSC())
         self.setProperty('fullPlatform', 'jsc-only')
         self.setProperty('configuration', 'debug')
         self.expectRemoteCommands(
@@ -884,7 +884,7 @@
         return self.runStep()
 
 
-class TestCompileJSCOnlyToT(BuildStepMixinAdditions, unittest.TestCase):
+class TestCompileJSCToT(BuildStepMixinAdditions, unittest.TestCase):
     def setUp(self):
         self.longMessage = True
         return self.setUpBuildStep()
@@ -893,7 +893,7 @@
         return self.tearDownBuildStep()
 
     def test_success(self):
-        self.setupStep(CompileJSCOnlyToT())
+        self.setupStep(CompileJSCToT())
         self.setProperty('fullPlatform', 'jsc-only')
         self.setProperty('configuration', 'release')
         self.setProperty('patchFailedToBuild', 'True')
@@ -908,7 +908,7 @@
         return self.runStep()
 
     def test_failure(self):
-        self.setupStep(CompileJSCOnlyToT())
+        self.setupStep(CompileJSCToT())
         self.setProperty('fullPlatform', 'jsc-only')
         self.setProperty('configuration', 'debug')
         self.setProperty('patchFailedToBuild', 'True')
@@ -924,7 +924,7 @@
         return self.runStep()
 
     def test_skip(self):
-        self.setupStep(CompileJSCOnlyToT())
+        self.setupStep(CompileJSCToT())
         self.setProperty('fullPlatform', 'jsc-only')
         self.setProperty('configuration', 'debug')
         self.expectHidden(True)
@@ -36,7 +36,7 @@
 from steps import (AnalyzeAPITestsResults, AnalyzeCompileWebKitResults, AnalyzeLayoutTestsResults, ApplyPatch, ApplyWatchList, ArchiveBuiltProduct, ArchiveTestResults,
                    CheckOutSource, CheckOutSpecificRevision, CheckPatchRelevance, CheckStyle, CleanBuild, CleanUpGitIndexLock, CleanWorkingDirectory,
-                   CompileJSCOnly, CompileJSCOnlyToT, CompileWebKit, CompileWebKitToT, ConfigureBuild,
+                   CompileJSC, CompileJSCToT, CompileWebKit, CompileWebKitToT, ConfigureBuild,
                    DownloadBuiltProduct, ExtractBuiltProduct, ExtractTestResults, InstallGtkDependencies, InstallWpeDependencies, KillOldProcesses,
                    PrintConfiguration, ReRunAPITests, ReRunJavaScriptCoreTests, ReRunWebKitTests, RunAPITests, RunAPITestsWithoutPatch,

Modified: trunk/Tools/ChangeLog (250256 => 250257)

